@@ -11,10 +11,10 @@ def _insert_default_placeholders(raw):
     for imp in raw:
         defaults[imp] = {}
         for key, data in raw[imp]["CONFIG"].items():
-            # if "default" in data:
-            if "default" in data:
-                defaults[imp][key] = data["default"]
-                data["default"] = _DefaultOption
+            if "default" not in data:
+                raise KeyError(f"No default value for '{key}' in '{imp}'s conf.py")
+            defaults[imp][key] = data["default"]
+            data["default"] = _DefaultOption
     return defaults
 
 
@@ -38,9 +38,9 @@ def _reroot_paths(defaults, root):
         for key, val in defaults[imp].items():
             if key == "root_dir":
                 defaults[imp][key] = root
-            elif (
-                key.endswith("_dir") or key.endswith("_path") or key.endswith("_file")
-            ) and os.path.isabs(val or ""):
+            elif (key.endswith(("_dir", "_path", "_file"))) and os.path.isabs(
+                val or ""
+            ):
                 # only update absolute paths for keys
                 #  ending in _dir, _path or _file
                 defaults[imp][key] = _reroot_path(val, imp, root)
