@@ -1,10 +1,10 @@
 """
 Find the conf.py files specified in sources
 """
-# Import python libs
-import importlib
 import copy
+import importlib
 import os.path
+
 import dict_tools.update
 
 
@@ -39,10 +39,10 @@ def load(hub, sources, dyne_names, cli):
         except ImportError:
             continue
         dict_tools.update.update(raw, data)
+    # Makes sure everything is unique
     dnames = set(dyne_names)
-    for source in raw:
-        for dname in raw[source]["DYNE"]:
-            dnames.add(dname)
+    for source in sources:
+        dnames.update(raw[source]["DYNE"].keys())
     for name in dnames:
         if name in dyne:
             if name not in raw:
