@@ -28,5 +28,6 @@ def load(
     hub.OPT = hub.pop.data.imap(opt)
 
     if logs:
-        log_plugin = hub.OPT[sources[0]].get("log_plugin")
-        getattr(hub, f"log.{log_plugin}.setup")(hub.OPT[sources[0]])
+        authoritative_cli = hub.OPT[sources[0]]
+        log_plugin = authoritative_cli.get("log_plugin")
+        hub.log[log_plugin].setup(authoritative_cli)
